@@ -47,11 +47,12 @@ use ZoneMinder::Database qw(:all);
 
 use POSIX;
 
-use vars qw/ $table $primary_key %fields %defaults $debug/;
-$debug = 0;
+use vars qw/ $serial $primark_key $table $primary_key %fields %defaults $debug/;
+$serial = $primary_key = 'Id';
+$debug = 1;
 $table = 'Storage';
 $primary_key = 'Id';
-%fields = map { $_ => $_ } qw( Id Name Path DoDelete ServerId Type Url DiskSpace Scheme );
+%fields = map { $_ => $_ } qw( Id Name Path DoDelete ServerId Type Url DiskSpace Scheme Enabled);
 
 %defaults = (
   Type => 'local',
@@ -92,50 +93,102 @@ sub Server {
   return $$self{Server};
 }
 
+sub s3 {
+  my $self = shift;
+  if (!$$self{s3}) {
+    my $url = $$self{Url};
+    $url =~ s/^(s3|s3fs):\/\///ig;
+    $url =~ /^\s*(?<ID>[^:]+):(?<SECRET>[^@]+)@(?<HOST>(https?:\/\/)?[^\/]*)\/(?<BUCKET>[^\/]+)(?<SUBPATH>\/.+)?\s*$/;
+    my ( $aws_id, $aws_secret, $aws_host, $aws_bucket, $subpath ) = ($+{ID},$+{SECRET}, $+{HOST}, $+{BUCKET}, $+{SUBPATH});
+    $$self{aws_bucket} = $aws_bucket;
+    $$self{aws_subpath} = $subpath;
+    $subpath = '' if !$subpath;
+    Debug("S3 url parsed to id:$aws_id secret:$aws_secret host:$aws_host, bucket:$aws_bucket, subpath:$subpath\n from $url");
+    if ($aws_id and $aws_secret and $aws_host and $aws_bucket) {
+      eval {
+        require Net::Amazon::S3;
+        require Net::Amazon::S3::Vendor::Generic;
+        my $vendor = undef;
+        if ($aws_host) {
+          $aws_host =~ s/^https?:\/\///ig;
+          $vendor = Net::Amazon::S3::Vendor::Generic->new(
+            host=>$aws_host,
+            authorization_method => 'Net::Amazon::S3::Signature::V4',
+            use_virtual_host => 0,
+          );
+        }
+        my $s3 = $$self{s3} = Net::Amazon::S3->new( {
+            aws_access_key_id     => $aws_id,
+            aws_secret_access_key => $aws_secret,
+            ( $vendor ? (vendor => $vendor) : (
+              )),
+          });
+        #$s3->ua(LWP::UserAgent->new(keep_alive => 0, requests_redirectable => [qw'GET HEAD DELETE PUT POST']));
+      };
+      Error($@) if $@;
+    } else {
+      Warning('Failed to parse s3fs url.');
+    } # end if parsed url
+  }
+  return $$self{s3};
+}
+
+sub bucket {
+  my $self = shift;
+  if (!$$self{bucket}) {
+    my $s3 = $self->s3();
+    if ($s3) {
+      my $bucket = $$self{bucket} = $s3->bucket($$self{aws_bucket});
+      if ( !$bucket ) {
+        Error("S3 bucket $bucket not found.");
+        die;
+      }
+    } # end if s3 
+  } # end if bucket
+  return $$self{bucket};
+}
+
+sub aws_subpath {
+  my $self = shift;
+  return defined($$self{aws_subpath}) ? $$self{aws_subpath} : '';
+}
+
 sub delete_path {
   my $self = shift;
   my $path = shift;
 
   my $deleted = 0;
   
-  Debug("Delete $path");
-  if ($$self{Type} and ( $$self{Type} eq 's3fs' )) {
-    my $url = $$self{Url};
-    $url =~ s/^(s3|s3fs):\/\///ig;
-    my ( $aws_id, $aws_secret, $aws_host, $aws_bucket, $subpath ) = ( $url =~ /^\s*([^:]+):([^@]+)@([^\/]*)\/([^\/]+)(\/.+)?\s*$/ );
-    Debug("S3 url parsed to id:$aws_id secret:$aws_secret host:$aws_host, bucket:$aws_bucket, subpath:$subpath\n from $url");
-    eval {
-      require Net::Amazon::S3;
-      my $s3 = Net::Amazon::S3->new( {
-          aws_access_key_id     => $aws_id,
-          aws_secret_access_key => $aws_secret,
-          ( $aws_host ? ( host => $aws_host ) : () ),
-          authorization_method => 'Net::Amazon::S3::Signature::V4',
-        });
-      my $bucket = $s3->bucket($aws_bucket);
-      if ( ! $bucket ) {
-        Error("S3 bucket $bucket not found.");
-        die;
-      }
-      if ( $bucket->delete_key($subpath.$path) ) {
-        $deleted = 1;
-      } else {
-        Error('Failed to delete from S3:'.$s3->err . ': ' . $s3->errstr);
-      }
-    };
-    Error($@) if $@;
+  if ($$self{Type} and ($$self{Type} eq 's3fs')) {
+    Debug("Delete $path");
+    my $s3 = $self->s3();
+    my $bucket = $self->bucket();
+    if ($s3 and $bucket) {
+      eval {
+        if ($bucket->delete_key($$self{aws_subpath}.$path)) {
+          $deleted = 1;
+        } else {
+          Error('Failed to delete from S3:'.$s3->err . ': ' . $s3->errstr);
+        }
+      };
+      Error($@) if $@;
+    } # end if s3
   } # end if s3fs
 
-  if ( !$deleted ) {
+  if (!$deleted) {
     my $storage_path = $self->Path();
-    ( $storage_path ) = ( $storage_path =~ /^(.*)$/ ); # De-taint
-    ( $path ) = ( $path =~ /^(.*)$/ ); # De-taint
-    my $command = "/bin/rm -rf $storage_path/$path 2>&1";
+    ($storage_path) = ($storage_path =~ /^(.*)$/); # De-taint
+    ($path) = ($path =~ /^(.*)$/); # De-taint
+    if (!$Config{ZM_PATH_RM}) {
+      Info('No value set for ZM_PATH_RM.  ZM_PATH_RM should have been set automatically by the distro in '.$Config{ZM_CONFIG_DIR}.'/conf.d/01-system-paths.conf. Defaulting to /bin/rm');
+      $Config{ZM_PATH_RM} = '/bin/rm';
+    }
+    my $command = "$Config{ZM_PATH_RM} -rf $storage_path/$path 2>&1";
     if (ZoneMinder::General::executeShellCommand($command)) {
-      Error("Error deleting event directory at $storage_path/$path");
+      Error("Error deleting event directory at $storage_path/$path using $command");
     }
   }
-}
+} # end sub delete_path
 
 1;
 __END__
