@@ -117,8 +117,10 @@ class EventStream : public StreamBase {
     delete ffmpeg_input;
   }
   void setStreamStart(uint64_t init_event_id, int init_frame_id);
-  void setStreamStart(int monitor_id, time_t event_time);
+  void setStreamStart(uint64_t init_event_id, SystemTimePoint event_time);
+  void setStreamStart(int monitor_id, SystemTimePoint event_time);
   void setStreamMode(StreamMode p_mode) { mode = p_mode; }
+  bool seek(SystemTimePoint event_time);
   void runStream() override;
   Image *getImage();
  private:
