@@ -35,7 +35,8 @@ PacketQueue::PacketQueue():
   keep_keyframes(false),
   warned_count(0),
   has_out_of_order_packets_(false),
-  max_keyframe_interval_(0)
+  max_keyframe_interval_(0),
+  frames_since_last_keyframe_(0)
 {
 }
 
@@ -90,134 +91,143 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
     std::unique_lock<std::mutex> lck(mutex);
     if (deleting or zm_terminate) return false;
 
-    if (!has_out_of_order_packets_ and (add_packet->packet->dts != AV_NOPTS_VALUE)) {
+    AVPacket *add_avpacket = add_packet->packet.get();  // because std::shared_ptr accesses are way more expensive
+    if (!has_out_of_order_packets_ and (add_avpacket->dts != AV_NOPTS_VALUE)) {
       auto rit = pktQueue.rbegin();
       // Find the previous packet for the stream, and check dts
       while (rit != pktQueue.rend()) {
         std::shared_ptr<ZMPacket> prev_packet = *rit;
 
-        if (prev_packet->packet->stream_index == add_packet->packet->stream_index) {
-          if (prev_packet->packet->dts > add_packet->packet->dts) {
+        if (prev_packet->packet->stream_index == add_avpacket->stream_index) {
+          if (prev_packet->packet->dts > add_avpacket->dts) {
             Debug(1, "Have out of order packets");
             ZM_DUMP_PACKET(prev_packet->packet, "queued_packet");
-            ZM_DUMP_PACKET(add_packet->packet, "add_packet");
+            ZM_DUMP_PACKET(add_avpacket, "add_packet");
             has_out_of_order_packets_ = true;
           }
           break;
         }
         rit++;
       }  // end while
-    }
+    }  // end if doing out_of_order checking
 
-    if (!max_keyframe_interval_ and add_packet->keyframe and (video_stream_id==add_packet->packet->stream_index)) {
-      auto rit = pktQueue.rbegin();
-      int packet_count = 0;
-      while (rit != pktQueue.rend()) {
-        if ((*rit)->packet->stream_index == add_packet->packet->stream_index) {
-          if ((*rit)->keyframe) break;
-          packet_count ++;
+    if (video_stream_id == add_avpacket->stream_index) {
+      if (!add_packet->keyframe) {
+        frames_since_last_keyframe_ ++;
+        if (frames_since_last_keyframe_ > max_keyframe_interval_) {
+          max_keyframe_interval_ = frames_since_last_keyframe_; 
+          Debug(1, "Have new keyframe interval %d", max_keyframe_interval_);
         }
-        ++rit;
+      } else {
+        frames_since_last_keyframe_ = 1;
+        if (!max_keyframe_interval_) max_keyframe_interval_ = 1;
       }
-      Debug(1, "Have keyframe interval: %d", packet_count);
-      max_keyframe_interval_ = packet_count;
+    } else {
+      Debug(1, "Not video stream %d", add_avpacket->stream_index);
     }
 
     pktQueue.push_back(add_packet);
-    packet_counts[add_packet->packet->stream_index] += 1;
-    Debug(2, "packet counts for %d is %d",
-        add_packet->packet->stream_index,
-        packet_counts[add_packet->packet->stream_index]);
 
     /* Any iterators that are pointing to the end will now point to the newly pushed packet */
     for (
-        auto iterators_it = iterators.begin();
-        iterators_it != iterators.end();
-        ++iterators_it
-        ) {
+      auto iterators_it = iterators.begin();
+      iterators_it != iterators.end();
+      ++iterators_it
+    ) {
       packetqueue_iterator *iterator_it = *iterators_it;
       if (*iterator_it == pktQueue.end()) {
         --(*iterator_it);
       }
     }  // end foreach iterator
 
+    packet_counts[add_avpacket->stream_index] += 1;
+    Debug(2, "packet counts for %d is %d", add_avpacket->stream_index, packet_counts[add_avpacket->stream_index]);
+
     if (
-        (add_packet->packet->stream_index == video_stream_id)
-        and
-        (max_video_packet_count > 0)
-        and
-        (packet_counts[video_stream_id] > max_video_packet_count)
-       ) {
+      (add_avpacket->stream_index == video_stream_id)
+      and
+      (max_video_packet_count > 0)
+      and
+      (packet_counts[video_stream_id] > max_video_packet_count)
+    ) {
       if (!warned_count) {
         warned_count++;
         Warning("You have set the max video packets in the queue to %u."
-            " The queue is full. Either Analysis is not keeping up or"
-            " your camera's keyframe interval %d is larger than this setting."
-            , max_video_packet_count, max_keyframe_interval_);
+                " The queue is full %u. Either Analysis is not keeping up or"
+                " your camera's keyframe interval %d is larger than this setting."
+                , max_video_packet_count, packet_counts[video_stream_id], max_keyframe_interval_);
       }
 
-      for (
-          // Start at second packet because the first is always a keyframe
-          auto it = ++pktQueue.begin();
-          //it != pktQueue.end() and  // can't hit end because we added our packet
-          (*it != add_packet) && !(deleting or zm_terminate);
-          // iterator is incremented by erase
-      ) {
+      // Going to delete a GOP of packets. So find another keyframe and delete everything before it.
+      auto it = pktQueue.begin();
+      // Start at second packet because the first is always a keyframe unless we don't care about keyframes
+      it ++;
+      while ((*it != add_packet) && !(deleting or zm_terminate)) {
         std::shared_ptr <ZMPacket>zm_packet = *it;
+        ZMPacketLock packet_lock(zm_packet);
 
-        ZMLockedPacket lp(zm_packet);
-        if (!lp.trylock()) {
+        if (zm_packet->packet->stream_index == video_stream_id and zm_packet->keyframe) {
+          for ( it = pktQueue.begin(); *it != zm_packet; ) {
+            it = this->deletePacket(it);
+          }
+          break;
+        }  // end if erasing a whole gop
+        // Don't need to lock the new keyframe, just everythig before it
+        if (!packet_lock.trylock()) {
+          // If we can't get a lock, then we can't delete a GOP.  I'm actually not sure about this.
+          // It means someone is playing with the packet but doesn't mean we can't remove it from the queue.
           if (warned_count < 2) {
             warned_count++;
-            // Can't delete a locked packet, but can delete one after it.
-            Warning("Found locked packet when trying to free up video packets. This means that decoding is not keeping up.");
+            Warning("Found locked packet %d when trying to free up video packets. Our packet %d", zm_packet->image_index, add_packet->image_index);
           }
-          ++it;
-          continue;
-        }
-
-        for (
-            auto iterators_it = iterators.begin();
-            iterators_it != iterators.end();
-            ++iterators_it
-            ) {
-          auto iterator_it = *iterators_it;
-          // Have to check each iterator and make sure it doesn't point to the packet we are about to delete
-          if (*(*iterator_it) == zm_packet) {
-            Debug(1, "Bumping IT because it is at the front that we are deleting");
-            ++(*iterator_it);
-          }
-        }  // end foreach iterator
-
-        zm_packet->decoded = true; // Have to in case analysis is waiting on it
-        zm_packet->notify_all();
-
-        it = pktQueue.erase(it);
-        packet_counts[zm_packet->packet->stream_index] -= 1;
-        Debug(1,
-            "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
-            zm_packet->packet->stream_index,
-            zm_packet->image_index,
-            zm_packet->keyframe,
-            packet_counts[video_stream_id],
-            max_video_packet_count,
-            pktQueue.size());
-
-        if (zm_packet->packet->stream_index == video_stream_id)
           break;
-      }  // end while
+        }
+        ++it;
+      }  // end foreach
     } else if (warned_count > 0) {
       warned_count--;
     }  // end if not able catch up
+    // We signal on every packet because someday we may analyze sound
+    Debug(4, "packetqueue queuepacket, unlocked signalling");
+    condition.notify_all();
   }  // end lock scope
-  // We signal on every packet because someday we may analyze sound
-  Debug(4, "packetqueue queuepacket, unlocked signalling");
-  condition.notify_all();
 
-	return true;
+  return true;
 }  // end bool PacketQueue::queuePacket(ZMPacket* zm_packet)
 
+packetqueue_iterator PacketQueue::deletePacket(packetqueue_iterator it) {
+  auto zm_packet = *it;
+  for (
+      auto iterators_it = iterators.begin();
+      iterators_it != iterators.end();
+      ++iterators_it
+      ) {
+    auto iterator_it = *iterators_it;
+    // Have to check each iterator and make sure it doesn't point to the packet we are about to delete
+    if (*(*iterator_it) == zm_packet) {
+      Debug(1, "Bumping IT because it is at the front that we are deleting");
+      ++(*iterator_it);
+    } else {
+      Debug(4, "Not Bumping IT because it is pointing at %d and we are %d", (*(*iterator_it))->image_index, zm_packet->image_index);
+    }
+  }  // end foreach iterator
+  zm_packet->decoded = true; // analysis waits on decoding status so won't progress until we set this. Although we loop so maybe not.
+  zm_packet->notify_all();
+
+  packet_counts[zm_packet->packet->stream_index] -= 1;
+  Debug(1,
+      "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
+      zm_packet->packet->stream_index,
+      zm_packet->image_index,
+      zm_packet->keyframe,
+      packet_counts[video_stream_id],
+      max_video_packet_count,
+      pktQueue.size());
+  return pktQueue.erase(it);
+}
+
 void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
+  std::lock_guard<std::mutex> lck(mutex);
   // Only do queueCleaning if we are adding a video keyframe, so that we guarantee that there is one.
   // No good.  Have to satisfy two conditions:
   // 1. packetqueue starts with a video keyframe
@@ -239,52 +249,56 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
         (packet_counts[video_stream_id] > pre_event_video_packet_count)
         and
         *(pktQueue.begin()) != add_packet
-        )
+      )
      ) {
     Debug(3, "stream index %d ?= video_stream_id %d, keyframe %d, keep_keyframes %d,  counts %d > pre_event_count %d at begin %d",
-        add_packet->packet->stream_index, video_stream_id, add_packet->keyframe, keep_keyframes, packet_counts[video_stream_id], pre_event_video_packet_count,
-        ( *(pktQueue.begin()) != add_packet )
-        );
+          add_packet->packet->stream_index, video_stream_id, add_packet->keyframe, keep_keyframes, packet_counts[video_stream_id], pre_event_video_packet_count,
+          ( *(pktQueue.begin()) != add_packet )
+         );
     return;
   }
-  std::unique_lock<std::mutex> lck(mutex);
 
   // If analysis_it isn't at the end, we need to keep that many additional packets
   int tail_count = 0;
-  if (pktQueue.back() != add_packet) {
-    packetqueue_iterator it = pktQueue.end();
-    --it;
-    while (*it != add_packet) {
-      if ((*it)->packet->stream_index == video_stream_id)
-        ++tail_count;
-      --it;
-    }
+  for (auto it = pktQueue.rbegin(); it != pktQueue.rend(); ++it) {
+    if (*it == add_packet) break;
+    if ((*it)->packet->stream_index == video_stream_id)
+      ++tail_count;
   }
-  Debug(1, "Tail count is %d, queue size is %" __PRIPTR_PREFIX "u", tail_count, pktQueue.size());
+  Debug(1, "Tail count is %d, queue size is %zu, video_packets %d", tail_count, pktQueue.size(), packet_counts[video_stream_id]);
 
   if (!keep_keyframes) {
+    int packets_removed = 0;
+    Debug(3, "Not keeping keyframes");
     // If not doing passthrough, we don't care about starting with a keyframe so logic is simpler
     while ((*pktQueue.begin() != add_packet) and (packet_counts[video_stream_id] > pre_event_video_packet_count + tail_count)) {
       std::shared_ptr<ZMPacket> zm_packet = *pktQueue.begin();
-      ZMLockedPacket lp(zm_packet);
-      if (!lp.trylock()) break;
-
-      if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
-        Warning("Found iterator at beginning of queue. Some thread isn't keeping up");
+      ZMPacketLock packet_lock(zm_packet);
+      if (!packet_lock.trylock()) {
+        Debug(1, "Failed locking packet %d", zm_packet->image_index);
         break;
       }
 
+      if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
+        Debug(1, "Found iterator at beginning of queue.");
+        break;
+      }
+
+      packets_removed ++;
       pktQueue.pop_front();
-      packet_counts[zm_packet->packet->stream_index] -= 1;
+      int stream_index = zm_packet->packet ? zm_packet->packet->stream_index : 0;
+      packet_counts[stream_index] -= 1;
       Debug(1,
             "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
-            zm_packet->packet->stream_index,
+            stream_index,
             zm_packet->image_index,
             zm_packet->keyframe,
             packet_counts[video_stream_id],
             pre_event_video_packet_count,
             pktQueue.size());
     } // end while
+    Debug(3, "Done removing %d packets from queue. packet_counts %d >? pre_event %d + tail %d = %d",
+        packets_removed, packet_counts[video_stream_id], pre_event_video_packet_count, tail_count, pre_event_video_packet_count + tail_count);
     return;
   }
 
@@ -298,36 +312,36 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
     return;
   }
 
-  int keyframe_interval_count = 1;
+  int keyframe_interval_count = 0;
   int video_packets_to_delete = 0;    // This is a count of how many packets we will delete so we know when to stop looking
 
-  ZMLockedPacket *lp = new ZMLockedPacket(zm_packet);
-  if (!lp->trylock()) {
-    Debug(4, "Failed getting lock on first packet");
-    delete lp;
-    return;
-  }  // end if first packet not locked
+  {
+    ZMPacketLock packet_lock(zm_packet);
+    if (!packet_lock.trylock()) {
+      Debug(4, "Failed getting lock on first packet");
+      return;
+    }  // end if first packet not locked
+   
+    if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
+      Debug(3, "Found iterator Counted %d video packets. Which would leave %d in packetqueue tail count is %d",
+          video_packets_to_delete, packet_counts[video_stream_id]-video_packets_to_delete, tail_count);
+      //zm_packet->unlock(); not necessary due to RAII
+      return;
+    }
 
-  if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
-    Debug(3, "Found iterator Counted %d video packets. Which would leave %d in packetqueue tail count is %d",
-        video_packets_to_delete, packet_counts[video_stream_id]-video_packets_to_delete, tail_count);
-    delete lp;
-    return;
+    ++it;
   }
 
-  ++it;
-  delete lp;
-
   // Since we have many packets in the queue, we should NOT be pointing at end so don't need to test for that
   while (*it != add_packet) {
     zm_packet = *it;
-    lp = new ZMLockedPacket(zm_packet);
-    if (!lp->trylock()) {
-      Debug(3, "Failed locking packet %d", zm_packet->image_index);
-      delete lp;
-      break;
+    {
+      ZMPacketLock packet_lock(zm_packet);
+      if (!packet_lock.trylock()) {
+        Debug(3, "Failed locking packet %d", zm_packet->image_index);
+        break;
+      }
     }
-    delete lp;
 
     if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
       Debug(3, "Found iterator Counted %d video packets. Which would leave %d in packetqueue tail count is %d",
@@ -347,18 +361,18 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
       ++video_packets_to_delete;
       if (packet_counts[video_stream_id] - video_packets_to_delete <= pre_event_video_packet_count + tail_count) {
         Debug(3, "Counted %d video packets. Which would leave %d in packetqueue tail count is %d",
-            video_packets_to_delete, packet_counts[video_stream_id]-video_packets_to_delete, tail_count);
+              video_packets_to_delete, packet_counts[video_stream_id]-video_packets_to_delete, tail_count);
         break;
       }
-    } // end while
+    }
     ++it;
-  }  // end if first packet not locked
+  } // end while
 
   Debug(1, "Resulting it pointing at latest packet? %d, next front points to begin? %d, Keyframe interval %d",
-      ( *it == add_packet ),
-      ( next_front == pktQueue.begin() ),
-      keyframe_interval_count
-      );
+        ( *it == add_packet ),
+        ( next_front == pktQueue.begin() ),
+        keyframe_interval_count
+       );
   if (next_front != pktQueue.begin()) {
     while (pktQueue.begin() != next_front) {
       zm_packet = *pktQueue.begin();
@@ -380,50 +394,51 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
     }
   }  // end if have at least max_video_packet_count video packets remaining
 
-	return;
+  return;
 } // end voidPacketQueue::clearPackets(ZMPacket* zm_packet)
 
 void PacketQueue::stop() {
-  deleting = true;
-  condition.notify_all();
+  {
+    std::lock_guard<std::mutex> lck(mutex);
+    deleting = true;
+    condition.notify_all();
+  }
   for (const auto &p : pktQueue) {
     p->notify_all();
   }
 }
 
 void PacketQueue::clear() {
+  Debug(1, "Clearing packetqueue");
+  std::lock_guard<std::mutex> lck(mutex);
   deleting = true;
   // Why are we notifying?
   condition.notify_all();
   if (!packet_counts) // special case, not initialised
     return;
-  Debug(1, "Clearing packetqueue");
-  std::unique_lock<std::mutex> lck(mutex);
 
   while (!pktQueue.empty()) {
     std::shared_ptr<ZMPacket> packet = pktQueue.front();
     // Someone might have this packet, but not for very long and since we have locked the queue they won't be able to get another one
-    ZMLockedPacket *lp = new ZMLockedPacket(packet);
-    lp->lock();
+    // Deleting this packet, doesn't require a lock.  We only need a lock if we are modifying the packet.  
     Debug(1,
-        "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
-        packet->packet->stream_index,
-        packet->image_index,
-        packet->keyframe,
-        packet_counts[video_stream_id],
-        pre_event_video_packet_count,
-        pktQueue.size());
+          "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
+          packet->packet->stream_index,
+          packet->image_index,
+          packet->keyframe,
+          packet_counts[video_stream_id],
+          pre_event_video_packet_count,
+          pktQueue.size());
     packet_counts[packet->packet->stream_index] -= 1;
     pktQueue.pop_front();
-    delete lp;
   }
   Debug(1, "Packetqueue is clear, deleting iterators");
 
   for (
-      std::list<packetqueue_iterator *>::iterator iterators_it = iterators.begin();
-      iterators_it != iterators.end();
-      ++iterators_it
-      ) {
+    std::list<packetqueue_iterator *>::iterator iterators_it = iterators.begin();
+    iterators_it != iterators.end();
+    ++iterators_it
+  ) {
     packetqueue_iterator *iterator_it = *iterators_it;
     *iterator_it = pktQueue.begin();
   }  // end foreach iterator
@@ -431,6 +446,7 @@ void PacketQueue::clear() {
   delete[] packet_counts;
   packet_counts = nullptr;
   max_stream_id = -1;
+  max_keyframe_interval_ = 0;
 
   Debug(1, "Packetqueue is clear, notifying");
   condition.notify_all();
@@ -448,9 +464,7 @@ int PacketQueue::packet_count(int stream_id) {
   return packet_counts[stream_id];
 }  // end int PacketQueue::packet_count(int stream_id)
 
-ZMLockedPacket *PacketQueue::get_packet_no_wait(packetqueue_iterator *it) {
-  if (deleting or zm_terminate)
-    return nullptr;
+ZMPacketLock PacketQueue::get_packet_no_wait(packetqueue_iterator *it) {
 
   Debug(4, "Locking in get_packet using it %p queue end? %d",
       std::addressof(*it), (*it == pktQueue.end()));
@@ -458,37 +472,39 @@ ZMLockedPacket *PacketQueue::get_packet_no_wait(packetqueue_iterator *it) {
   // scope for lock
   std::unique_lock<std::mutex> lck(mutex);
   Debug(4, "Have Lock in get_packet");
+  if (deleting or zm_terminate)
+    return ZMPacketLock();
   if ((*it == pktQueue.end()) and !(deleting or zm_terminate)) {
     Debug(2, "waiting.  Queue size %zu it == end? %d", pktQueue.size(), (*it == pktQueue.end()));
     condition.wait(lck);
   }
-  if ((*it == pktQueue.end()) or deleting or zm_terminate) return nullptr;
+  if ((*it == pktQueue.end()) or deleting or zm_terminate) return ZMPacketLock();
 
   std::shared_ptr<ZMPacket> p = *(*it);
-  ZMLockedPacket *lp = new ZMLockedPacket(p);
-  if (lp->trylock()) {
+  ZMPacketLock packet_lock(p);
+  if (packet_lock.trylock()) {
     Debug(2, "Locked packet %d, unlocking packetqueue mutex", p->image_index);
-    return lp;
+    return packet_lock;
   }
-  delete lp;
-  return nullptr;
+  //Debug(1, "Failed to lock packet %d, returning... something?", p->image_index);
+  return ZMPacketLock();
 }
 
 // Returns a packet. Packet will be locked
-ZMLockedPacket *PacketQueue::get_packet(packetqueue_iterator *it) {
+ZMPacketLock PacketQueue::get_packet(packetqueue_iterator *it) {
   if (deleting or zm_terminate)
-    return nullptr;
+    return ZMPacketLock();
 
   Debug(4, "Locking in get_packet using it %p queue end? %d",
         std::addressof(*it), (*it == pktQueue.end()));
 
-  ZMLockedPacket *lp = nullptr;
-  { // scope for lock
+  {
+    // scope for lock
     std::unique_lock<std::mutex> lck(mutex);
     Debug(4, "Have Lock in get_packet");
-    while (!lp) {
+    while (!(deleting or zm_terminate)) {
       while ((*it == pktQueue.end()) and !(deleting or zm_terminate)) {
-        Debug(2, "waiting.  Queue size %zu it == end? %d", pktQueue.size(), (*it == pktQueue.end()));
+        Debug(4, "waiting.  Queue size %zu it == end? %d", pktQueue.size(), (*it == pktQueue.end()));
         condition.wait(lck);
       }
       if (deleting or zm_terminate) break;
@@ -496,43 +512,42 @@ ZMLockedPacket *PacketQueue::get_packet(packetqueue_iterator *it) {
       std::shared_ptr<ZMPacket> p = *(*it);
       if (!p) {
         Error("Null p?!");
-        return nullptr;
+        return ZMPacketLock();
       }
-      Debug(3, "get_packet using it %p locking index %d",
-          std::addressof(*it), p->image_index);
+      Debug(3, "get_packet using it %p trylocking index %d", std::addressof(*it), p->image_index);
 
-      lp = new ZMLockedPacket(p);
-      if (lp->trylock()) {
-        Debug(2, "Locked packet %d, unlocking packetqueue mutex", p->image_index);
-        return lp;
+      {
+        std::shared_ptr<ZMPacket> p = *(*it);
+        ZMPacketLock packet_lock(p);
+        if (packet_lock.trylock()) {
+          Debug(4, "Locked packet %d, unlocking packetqueue mutex", p->image_index);
+          return packet_lock;
+        }
       }
-      delete lp;
-      lp = nullptr;
-      Debug(2, "waiting.  Queue size %zu it == end? %d", pktQueue.size(), (*it == pktQueue.end()));
+      
+      Debug(4, "waiting on packet %d.  Queue size %zu it == end? %d", p->image_index, pktQueue.size(), (*it == pktQueue.end()));
       condition.wait(lck);
-    }  // end while !lp
+    }  // end while ! deleting or zm_terminate
+    condition.notify_all();
   }  // end scope for lock
 
-  if (!lp) {
-    Debug(1, "terminated, leaving");
-    condition.notify_all();
-  }
-  return lp;
-}  // end ZMLockedPacket *PacketQueue::get_packet(it)
+  Debug(1, "terminated, leaving");
+  return ZMPacketLock();
+}  // end ZMPacketLock *PacketQueue::get_packet(it)
 
 // Returns a packet. Packet will be locked
-ZMLockedPacket *PacketQueue::get_packet_and_increment_it(packetqueue_iterator *it) {
+ZMPacketLock PacketQueue::get_packet_and_increment_it(packetqueue_iterator *it) {
   if (deleting or zm_terminate)
-    return nullptr;
+    return ZMPacketLock();
 
   Debug(4, "Locking in get_packet using it %p queue end? %d",
         std::addressof(*it), (*it == pktQueue.end()));
 
-  ZMLockedPacket *lp = nullptr;
-  { // scope for lock
+  {
+    // scope for lock
     std::unique_lock<std::mutex> lck(mutex);
     Debug(4, "Have Lock in get_packet");
-    while (!lp) {
+    while (!(deleting or zm_terminate)) {
       while ((*it == pktQueue.end()) and !(deleting or zm_terminate)) {
         Debug(2, "waiting.  Queue size %zu it == end? %d", pktQueue.size(), (*it == pktQueue.end()));
         condition.wait(lck);
@@ -542,42 +557,38 @@ ZMLockedPacket *PacketQueue::get_packet_and_increment_it(packetqueue_iterator *i
       std::shared_ptr<ZMPacket> p = *(*it);
       if (!p) {
         Error("Null p?!");
-        return nullptr;
+        break;
       }
-      Debug(3, "get_packet using it %p locking index %d",
-          std::addressof(*it), p->image_index);
+      Debug(3, "get_packet using it %p locking index %d", std::addressof(*it), p->image_index);
 
-      lp = new ZMLockedPacket(p);
-      if (lp->trylock()) {
-        Debug(2, "Locked packet %d, unlocking packetqueue mutex, incrementing it", p->image_index);
-        ++(*it);
-        return lp;
+      {
+        ZMPacketLock packet_lock(p);
+        if (packet_lock.trylock()) {
+          Debug(2, "Locked packet %d, unlocking packetqueue mutex, incrementing it", p->image_index);
+          ++(*it);
+          return packet_lock;
+        }
       }
-      delete lp;
-      lp = nullptr;
       Debug(2, "waiting.  Queue size %zu it == end? %d", pktQueue.size(), (*it == pktQueue.end()));
       condition.wait(lck);
     }  // end while !lp
   }  // end scope for lock
 
-  if (!lp) {
-    Debug(1, "terminated, leaving");
-    condition.notify_all();
-  }
-  return lp;
-}  // end ZMLockedPacket *PacketQueue::get_packet_and_increment_it(it)
+  return ZMPacketLock();
+}  // end ZMPacketLock *PacketQueue::get_packet_and_increment_it(it)
 
-void PacketQueue::unlock(ZMLockedPacket *lp) {
+void PacketQueue::unlock(ZMPacketLock *lp) {
   delete lp;
   condition.notify_all();
 }
 
 bool PacketQueue::increment_it(packetqueue_iterator *it) {
-  Debug(2, "Incrementing %p, queue size %zu, end? %d", it, pktQueue.size(), ((*it) == pktQueue.end()));
+  std::lock_guard<std::mutex> lck(mutex);
+  Debug(2, "Incrementing %p, queue size %zu, end? %d, deleting %d", it, pktQueue.size(), ((*it) == pktQueue.end()), deleting);
   if (((*it) == pktQueue.end()) or deleting) {
+    if (!deleting) Warning("increment_it at end!");
     return false;
   }
-  std::unique_lock<std::mutex> lck(mutex);
   ++(*it);
   if (*it != pktQueue.end()) {
     Debug(2, "Incrementing %p, %p still not at end, so returning true", it, std::addressof(*it));
@@ -590,11 +601,12 @@ bool PacketQueue::increment_it(packetqueue_iterator *it) {
 // Increment it only considering packets for a given stream
 bool PacketQueue::increment_it(packetqueue_iterator *it, int stream_id) {
   Debug(2, "Incrementing %p, queue size %zu, end? %d", it, pktQueue.size(), (*it == pktQueue.end()));
+
+  std::lock_guard<std::mutex> lck(mutex);
   if (*it == pktQueue.end()) {
     return false;
   }
 
-  std::unique_lock<std::mutex> lck(mutex);
   do {
     ++(*it);
   } while ( (*it != pktQueue.end()) and ( (*(*it))->packet->stream_index != stream_id) );
@@ -607,33 +619,37 @@ bool PacketQueue::increment_it(packetqueue_iterator *it, int stream_id) {
 }  // end bool PacketQueue::increment_it(packetqueue_iterator *it)
 
 packetqueue_iterator *PacketQueue::get_event_start_packet_it(
-    packetqueue_iterator snapshot_it,
-    unsigned int pre_event_count
-    ) {
-  std::unique_lock<std::mutex> lck(mutex);
+  packetqueue_iterator snapshot_it,
+  unsigned int pre_event_count
+) {
+  std::lock_guard<std::mutex> lck(mutex);
 
   packetqueue_iterator *it = new packetqueue_iterator;
   iterators.push_back(it);
-  Debug(4, "Have event start iterator %p", std::addressof(*it));
 
   *it = snapshot_it;
+  if (*it == pktQueue.end()) (*it)--; // Should make it = pktQueue.begin
+ 
   std::shared_ptr<ZMPacket> packet = *(*it);
-  //ZM_DUMP_PACKET(packet->packet, "");
+  //ZM_DUMP_PACKET(packet->packet, "snapshot packet");
   // Step one count back pre_event_count frames as the minimum
   // Do not assume that snapshot_it is video
   // snapshot it might already point to the beginning
   while (pre_event_count and ((*it) != pktQueue.begin())) {
+    
     /*
     Debug(1, "Previous packet pre_event_count %d stream_index %d keyframe %d score %d",
         pre_event_count, packet->packet->stream_index, packet->keyframe, packet->score);
     ZM_DUMP_PACKET(packet->packet, "");
     */
+    
     if (packet->packet->stream_index == video_stream_id)
       pre_event_count --;
     (*it)--;
     packet = *(*it);
   }
 
+  // it either points to beginning or we have seen pre_event_count video packets.
   if (pre_event_count) {
     if (packet->image_index < (int)pre_event_count) {
       // probably just starting up
@@ -666,7 +682,7 @@ void PacketQueue::dumpQueue() {
   std::list<std::shared_ptr<ZMPacket>>::reverse_iterator it;
   for ( it = pktQueue.rbegin(); it != pktQueue.rend(); ++ it ) {
     std::shared_ptr<ZMPacket> zm_packet = *it;
-    ZM_DUMP_PACKET(zm_packet->packet, "");
+    ZM_DUMP_PACKET(zm_packet->packet, is_there_an_iterator_pointing_to_packet(zm_packet) ? "*" : "");
   }
 }
 
@@ -687,6 +703,7 @@ packetqueue_iterator * PacketQueue::get_video_it(bool wait) {
       *it = pktQueue.begin();
     }
     if ( deleting or zm_terminate ) {
+      // Isn't this redundant?
       free_it(it);
       delete it;
       return nullptr;
@@ -701,7 +718,7 @@ packetqueue_iterator * PacketQueue::get_video_it(bool wait) {
       return nullptr;
     }
     Debug(1, "Packet keyframe %d for stream %d, so returning the it to it",
-        zm_packet->keyframe, zm_packet->packet->stream_index);
+          zm_packet->keyframe, zm_packet->packet->stream_index);
     if (zm_packet->keyframe and ( zm_packet->packet->stream_index == video_stream_id )) {
       Debug(1, "Found a keyframe for stream %d, so returning the it to it", video_stream_id);
       return it;
@@ -713,25 +730,26 @@ packetqueue_iterator * PacketQueue::get_video_it(bool wait) {
 }  // get video_it
 
 void PacketQueue::free_it(packetqueue_iterator *it) {
-  std::unique_lock<std::mutex> lck(mutex);
+  std::lock_guard<std::mutex> lck(mutex);
   for (
-      std::list<packetqueue_iterator *>::iterator iterators_it = iterators.begin();
-      iterators_it != iterators.end();
-      ++iterators_it
-      ) {
-    if ( *iterators_it == it ) {
-      iterators.erase(iterators_it);
+    std::list<packetqueue_iterator *>::iterator iterators_it = iterators.begin();
+    iterators_it != iterators.end();
+    ++iterators_it
+  ) {
+    if (*iterators_it == it) {
+      delete *iterators_it; // delete the iterator
+      iterators.erase(iterators_it); // this will delete the pointer to it.
       break;
     }
   }
 }
 
-bool PacketQueue::is_there_an_iterator_pointing_to_packet(const std::shared_ptr<ZMPacket> &zm_packet) {
+bool PacketQueue::is_there_an_iterator_pointing_to_packet(const std::shared_ptr<ZMPacket> zm_packet) {
   for (
-      std::list<packetqueue_iterator *>::iterator iterators_it = iterators.begin();
-      iterators_it != iterators.end();
-      ++iterators_it
-      ) {
+    std::list<packetqueue_iterator *>::iterator iterators_it = iterators.begin();
+    iterators_it != iterators.end();
+    ++iterators_it
+  ) {
     packetqueue_iterator *iterator_it = *iterators_it;
     if (*iterator_it == pktQueue.end()) {
       Debug(4, "Checking iterator %p == end", std::addressof(*iterator_it));
