@@ -30,7 +30,7 @@ require_once('logger.php');
 function dbConnect() {
   global $dbConn;
 
-  $dsn = ZM_DB_TYPE == 'MariaDB' ? 'mysql' : ZM_DB_TYPE;
+  $dsn = ZM_DB_TYPE;
   if ( ZM_DB_HOST ) {
     if ( strpos(ZM_DB_HOST, ':') ) {
       // Host variable may carry a port or socket.
@@ -224,8 +224,8 @@ function dbFetchNext($result, $col=false) {
   return false;
 }
 
-function dbNumRows( $sql ) {
-  $result = dbQuery($sql);
+function dbNumRows($sql, $params=NULL) {
+  $result = dbQuery($sql, $params);
   return $result->rowCount();
 }
 
@@ -379,4 +379,55 @@ function getTableDescription( $table, $asString=1 ) {
   }
   return $columns;
 }
+
+function db_version() {
+  return dbFetchOne('SELECT VERSION()', 'VERSION()');
+}
+
+function db_supports_feature($feature) {
+  $version = db_version();
+  if ($feature == 'skip_locks') {
+    $just_the_version = strstr($version, '-MariaDB', true);
+    if (false === $just_the_version) {
+      # Is MYSQL
+      return version_compare($version, '8.0.1', '>=');
+    } else {
+      return version_compare($just_the_version, '10.6', '>=');
+    }
+  } else {
+    ZM\Warning("Unknown feature requested $feature");
+  }
+}
+
+function dbInsert($table, $fieldArray) {
+  $query = 'INSERT INTO `' . $table . '` SET ';
+  $fields = [];
+  $conditions = [];
+  $values = [];
+  foreach ($fieldArray as $fieldName => $fieldValue) {
+    $fields[] = '`' . $fieldName.'`=?';
+    $values[] = $fieldValue;
+  }
+  $query .= implode(', ', $fields);
+  return dbQuery($query, $values);
+}
+
+function dbUpdate($table, $fieldArray, $conditionArray) {
+  $query = 'UPDATE `' . $table . '` SET ';
+  $fields = [];
+  $conditions = [];
+  $values = [];
+  foreach ($fieldArray as $fieldName => $fieldValue) {
+    $fields[] = '`' . $fieldName.'`=?';
+    $values[] = $fieldValue;
+  }
+  $query .= implode(', ', $fields);
+  $query .= ' WHERE ';
+  foreach ($conditionArray as $fieldName => $fieldValue) {
+    $conditions[] = '`' . $fieldName . '` = ?';
+    $values[] = $fieldValue;
+  }
+  $query .= implode(' AND ', $conditions);
+  return dbQuery($query, $values);
+}
 ?>
