@@ -451,6 +451,12 @@ $SLANG = array(
     'OnvifProbe'            => 'ONVIF',
     'OnvifProbeIntro'       => 'The list below shows detected ONVIF cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>',
     'OnvifCredentialsIntro' => 'Please supply user name and password for the selected camera.<br/>If no user has been created for the camera then the user given here will be created with the given password.<br/><br/>',
+    'ONVIF'                 => 'ONVIF',
+    'ONVIF_Alarm_Text'      => 'ONVIF Alarm Text',
+    'ONVIF_Event_Listener'  => 'ONVIF Event Listener',
+    'ONVIF_EVENTS_PATH'     => 'ONVIF Events Path',
+    'ONVIF_Options'         => 'ONVIF Options',
+    'ONVIF_URL'             => 'ONVIF URL',
     'OpBlank'               => 'is blank',
     'OpEq'                  => 'equal to',
     'OpGtEq'                => 'greater than or equal to',
@@ -478,6 +484,7 @@ $SLANG = array(
     'PanTilt'               => 'Pan/Tilt',
     'ParentGroup'           => 'Parent Group',
     'PasswordsDifferent'    => 'The new and confirm passwords are different',
+    'Password'              => 'Password',
     'PathToIndex'           => 'Path To Index',
     'PathToZMS'             => 'Path To ZMS',
     'PathToApi'             => 'Path To Api',
@@ -585,6 +592,7 @@ $SLANG = array(
     'SourceColours'         => 'Source Colours',
     'SourcePath'            => 'Source Path',
     'SourceType'            => 'Source Type',
+    'SOAP WSA COMPLIANCE'   => 'SOAP WSA Compliance',
     'SpeedHigh'             => 'High Speed',
     'SpeedLow'              => 'Low Speed',
     'SpeedMedium'           => 'Medium Speed',
@@ -624,6 +632,7 @@ $SLANG = array(
     'UpdateAvailable'       => 'An update to ZoneMinder is available.',
     'UpdateNotNecessary'    => 'No update is necessary.',
     'UsedPlugins'	          => 'Used Plugins',
+    'Username'              => 'Username',
     'UseFilterExprsPost'    => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'     => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
     'UseFilter'             => 'Use Filter',
