@@ -4,8 +4,6 @@
 
 const COMPACT_MONTAGE = <?php echo ZM_WEB_COMPACT_MONTAGE ?>;
 const POPUP_ON_ALARM = <?php echo ZM_WEB_POPUP_ON_ALARM ?>;
-const ZM_DIR_SOUNDS = '<?php echo ZM_DIR_SOUNDS ?>';
-
 const statusRefreshTimeout = <?php echo 1000*ZM_WEB_REFRESH_STATUS ?>;
 
 const canStreamNative = <?php echo canStreamNative()?'true':'false' ?>;
@@ -26,7 +24,7 @@ monitorData[monitorData.length] = {
   'connKey': '<?php echo $monitor->connKey() ?>',
   'width': <?php echo $monitor->ViewWidth() ?>,
   'height':<?php echo $monitor->ViewHeight() ?>,
-  'scale':<?php echo $monitor->initial_scale() ?>,
+  'scale': '<?php echo $monitor->initial_scale() ?>',
   'RTSP2WebEnabled':<?php echo $monitor->RTSP2WebEnabled() ?>,
   'DefaultPlayer':'<?php echo $monitor->DefaultPlayer() ?>',
   'RTSP2WebStream':'<?php echo $monitor->RTSP2WebStream() ?>',
