@@ -2,12 +2,9 @@
 // Import constants
 //
 
-const ZM_DIR_SOUNDS = '<?php echo ZM_DIR_SOUNDS ?>';
-
 <?php
   global $presets;
   global $zone;
-  global $newZone;
   global $monitor;
   global $selfIntersecting;
   global $streamMode;
@@ -53,9 +50,9 @@ var zone = {
 
 zone['Points'] = new Array();
 <?php
-for ( $i = 0; $i < count($newZone['Points']); $i++ ) {
+for ( $i = 0; $i < count($zone['Points']); $i++ ) {
 ?>
-zone['Points'][<?php echo $i ?>] = { 'x': <?php echo $newZone['Points'][$i]['x'] ?>, 'y': <?php echo $newZone['Points'][$i]['y'] ?> };
+zone['Points'][<?php echo $i ?>] = { 'x': <?php echo $zone['Points'][$i]['x'] ?>, 'y': <?php echo $zone['Points'][$i]['y'] ?> };
 <?php
 }
 ?>
